Stan Math Library: stan/math/prim/mat/fun/log_sum_exp.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
log_sum_exp.hpp File Reference
`#include <stan/math/prim/scal/fun/log1p.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <boost/math/tools/promotion.hpp>`
`#include <limits>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<int R, int C>
double | stan::math::log_sum_exp (const Eigen::Matrix< double, R, C > &x)
| Return the log of the sum of the exponentiated values of the specified matrix of values. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.